SplitFileSystem

Struct SplitFileSystem 

pub struct SplitFileSystem<FS: RawFileSystem> { /* private fields */ }
A filesystem that splits files into clusters.

A cluster contains cluster_size blocks. When cluster_size is large enough, this filesystem is equivalent to the underlying filesystem.

Lower cluster_size implies better file size obfuscation, but also a higher overhead (both performance and storage).

Implementations

Source

impl<FS: RawFileSystem> SplitFileSystem<FS>

pub fn new(inner: FS, db: Arc<Database>, cluster_size: u64) -> Self